@@ -1,4 +1,4 @@
-#   Copyright 2024 The PyMC Developers
+#   Copyright 2024 - present The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -59,7 +59,6 @@ from pymc.distributions.continuous import (
     HalfFlatRV,
     HalfStudentTRV,
     KumaraswamyRV,
-    LogitNormalRV,
     MoyalRV,
     PolyaGammaRV,
     RiceRV,
@@ -70,7 +69,7 @@ from pymc.distributions.continuous import (
 )
 from pymc.distributions.discrete import DiscreteUniformRV
 from pymc.distributions.distribution import DiracDeltaRV
-from pymc.distributions.mixture import MarginalMixtureRV
+from pymc.distributions.mixture import MixtureRV
 from pymc.distributions.multivariate import (
     CARRV,
     DirichletMultinomialRV,
@@ -290,17 +289,12 @@ def logistic_mean(op, rv, rng, size, mu, s):
     return maybe_resize(pt.broadcast_arrays(mu, s)[0], size)
 
 
-@_mean.register(LogitNormalRV)
-def logitnormal_mean(op, rv, rng, size, mu, sigma):
-    raise UndefinedMomentException("The mean of the LogitNormal distribution is undefined")
-
-
 @_mean.register(LogNormalRV)
 def lognormal_mean(op, rv, rng, size, mu, sigma):
     return maybe_resize(pt.exp(mu + 0.5 * sigma**2), size)
 
 
-@_mean.register(MarginalMixtureRV)
+@_mean.register(MixtureRV)
 def marginal_mixture_mean(op, rv, rng, weights, *components):
     ndim_supp = components[0].owner.op.ndim_supp
     weights = pt.shape_padright(weights, ndim_supp)
