@@ -13,7 +13,6 @@
 #   limitations under the License.
 import functools as ft
 import itertools as it
-import warnings
 
 from collections.abc import Callable, Sequence
 from typing import Any
@@ -21,15 +20,21 @@ from typing import Any
 import numpy as np
 import pytensor
 import pytensor.tensor as pt
+import xarray as xr
 
 from arviz import InferenceData
 from numpy import random as nr
 from numpy import testing as npt
-from pytensor.compile.mode import Mode
-from pytensor.graph.basic import Variable
+from numpy.typing import NDArray
+from pytensor.compile import SharedVariable
+from pytensor.compile.mode import Mode, get_default_mode
+from pytensor.graph.basic import Constant, Variable, equal_computations
 from pytensor.graph.rewriting.basic import in2out
+from pytensor.graph.traversal import graph_inputs
+from pytensor.link.numba import NumbaLinker
 from pytensor.tensor import TensorVariable
 from pytensor.tensor.random.op import RandomVariable
+from pytensor.tensor.random.type import RandomType
 from scipy import special as sp
 from scipy import stats as st
 
@@ -42,9 +47,8 @@ from pymc.logprob.basic import icdf, logcdf, logp, transformed_conditional_logp
 from pymc.logprob.utils import (
     ParameterValueError,
     local_check_parameter_to_ninf_switch,
-    rvs_in_graph,
 )
-from pymc.pytensorf import compile, floatX, inputvars
+from pymc.pytensorf import compile, floatX, inputvars, rvs_in_graph
 
 # This mode can be used for tests where model compilations takes the bulk of the runtime
 # AND where we don't care about posterior numerical or sampling stability (e.g., when
@@ -665,12 +669,50 @@ def check_selfconsistency_discrete_logcdf(
             )
 
 
-def assert_moment_is_expected(model, expected, check_finite_logp=True):
-    warnings.warn(
-        "assert_moment_is_expected is deprecated. Use assert_support_point_is_expected instead.",
-        FutureWarning,
-    )
-    assert_support_point_is_expected(model, expected, check_finite_logp=check_finite_logp)
+def check_selfconsistency_icdf(
+    distribution: Distribution,
+    paramdomains: dict[str, Domain],
+    *,
+    decimal: int | None = None,
+    n_samples: int = 100,
+) -> None:
+    """Check that the icdf and logcdf functions of the distribution are consistent.
+
+    Only works with continuous distributions.
+    """
+    if decimal is None:
+        decimal = select_by_precision(float64=6, float32=3)
+
+    dist = create_dist_from_paramdomains(distribution, paramdomains)
+    if dist.type.dtype.startswith("int"):
+        raise NotImplementedError(
+            "check_selfconsistency_icdf is not robust against discrete distributions."
+        )
+    value = dist.astype("float64").type("value")
+    dist_icdf = icdf(dist, value)
+    dist_cdf = pt.exp(logcdf(dist, value))
+
+    py_mode = Mode("py")
+    dist_icdf_fn = pytensor.function(list(inputvars(dist_icdf)), dist_icdf, mode=py_mode)
+    dist_cdf_fn = compile(list(inputvars(dist_cdf)), dist_cdf, mode=py_mode)
+
+    domains = paramdomains.copy()
+    domains["value"] = Domain(np.linspace(0, 1, 10))
+
+    for point in product(domains, n_samples=n_samples):
+        point = dict(point)
+        value = point.pop("value")
+        icdf_value = dist_icdf_fn(**point, value=value)
+        recovered_value = dist_cdf_fn(
+            **point,
+            value=icdf_value,
+        )
+        np.testing.assert_almost_equal(
+            value,
+            recovered_value,
+            decimal=decimal,
+            err_msg=f"point: {point}",
+        )
 
 
 def assert_support_point_is_expected(model, expected, check_finite_logp=True):
@@ -910,6 +952,15 @@ class BaseTestDistributionRandom:
             self.pymc_rv.eval(), self.reference_dist_draws, decimal=self.decimal
         )
 
+    def check_pymc_draws_match_reference_not_numba(self):
+        # This calls `check_pymc_draws_match_reference` but only if the default linker is NOT numba.
+        # It's used when the draws aren't expected to match in that backend.
+        if isinstance(get_default_mode().linker, NumbaLinker):
+            return
+        npt.assert_array_almost_equal(
+            self.pymc_rv.eval(), self.reference_dist_draws, decimal=self.decimal
+        )
+
     def check_pymc_params_match_rv_op(self):
         op = self.pymc_rv.owner.op
         if isinstance(op, RandomVariable):
@@ -980,12 +1031,18 @@ def seeded_numpy_distribution_builder(dist_name: str) -> Callable:
 
 def assert_no_rvs(vars: Sequence[Variable]) -> None:
     """Assert that there are no `MeasurableOp` nodes in a graph."""
-    rvs = rvs_in_graph(vars)
-    if rvs:
+    if rvs := rvs_in_graph(vars):
         raise AssertionError(f"RV found in graph: {rvs}")
 
 
-def mock_sample(draws: int = 10, **kwargs):
+SampleStatsCreator = Callable[[tuple[int, int]], NDArray]
+
+
+def mock_sample(
+    draws: int = 10,
+    sample_stats: dict[str, SampleStatsCreator] | None = None,
+    **kwargs,
+) -> InferenceData:
     """Mock :func:`pymc.sample` with :func:`pymc.sample_prior_predictive`.
 
     Useful for testing models that use pm.sample without running MCMC sampling.
@@ -1015,15 +1072,47 @@ def mock_sample(draws: int = 10, **kwargs):
 
             pm.sample = original_sample
 
+    By default, the sample_stats group is not created. Pass a dictionary of functions
+    that create sample statistics, where the keys are the names of the statistics
+    and the values are functions that take a size tuple and return an array of that size.
+
+    .. code-block:: python
+
+        from functools import partial
+
+        import numpy as np
+        from numpy.typing import NDArray
+
+        from pymc.testing import mock_sample
+
+
+        def mock_diverging(size: tuple[int, int]) -> NDArray:
+            return np.zeros(size)
+
+
+        def mock_tree_depth(size: tuple[int, int]) -> NDArray:
+            return np.random.choice(range(2, 10), size=size)
+
+
+        mock_sample_with_stats = partial(
+            mock_sample,
+            sample_stats={
+                "diverging": mock_diverging,
+                "tree_depth": mock_tree_depth,
+            },
+        )
+
     """
     random_seed = kwargs.get("random_seed", None)
     model = kwargs.get("model", None)
     draws = kwargs.get("draws", draws)
     n_chains = kwargs.get("chains", 1)
+    var_names = kwargs.get("var_names", None)
     idata: InferenceData = pm.sample_prior_predictive(
         model=model,
         random_seed=random_seed,
         draws=draws,
+        var_names=var_names,
     )
 
     idata.add_groups(
@@ -1037,6 +1126,16 @@ def mock_sample(draws: int = 10, **kwargs):
     del idata["prior"]
     if "prior_predictive" in idata:
         del idata["prior_predictive"]
+
+    if sample_stats is not None:
+        sizes = idata["posterior"].sizes
+        size = (sizes["chain"], sizes["draw"])
+        sample_stats_ds = xr.Dataset(
+            {name: (("chain", "draw"), creator(size)) for name, creator in sample_stats.items()},
+            coords=idata["posterior"].coords,
+        )
+        idata.add_groups(sample_stats=sample_stats_ds)
+
     return idata
 
 
@@ -1095,3 +1194,28 @@ def mock_sample_setup_and_teardown():
     pm.sample = original_sample
     pm.Flat = original_flat
     pm.HalfFlat = original_half_flat
+
+
+def equal_computations_up_to_root(
+    xs: Sequence[Variable], ys: Sequence[Variable], ignore_rng_values=True
+) -> bool:
+    # Check if graphs are equivalent even if root variables have distinct identities
+
+    x_graph_inputs = [var for var in graph_inputs(xs) if not isinstance(var, Constant)]
+    y_graph_inputs = [var for var in graph_inputs(ys) if not isinstance(var, Constant)]
+    if len(x_graph_inputs) != len(y_graph_inputs):
+        return False
+    for x, y in zip(x_graph_inputs, y_graph_inputs):
+        if x.type != y.type:
+            return False
+        if x.name != y.name:
+            return False
+        if isinstance(x, SharedVariable):
+            if not isinstance(y, SharedVariable):
+                return False
+            if isinstance(x.type, RandomType) and ignore_rng_values:
+                continue
+            if not x.type.values_eq(x.get_value(), y.get_value()):
+                return False
+
+    return equal_computations(xs, ys, in_xs=x_graph_inputs, in_ys=y_graph_inputs)  # type: ignore[arg-type]
